clusterutils

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2026 License: Apache-2.0 Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConfigByPrefix

func ConfigByPrefix(prefix string, namespace string) (*envconf.Config, error)

ConfigByPrefix returns an environment Config with the passed in namespace and a klient that is set up to interact with the cluster identified by the passed in cluster name prefix

func ImportToMCPCluster added in v0.3.0

func ImportToMCPCluster(ctx context.Context, c *envconf.Config, mcpName, dir string, options ...wait.Option) (*unstructured.UnstructuredList, error)

ImportToMcpCluster applies a set of resources from a directory to the mcp cluster

func ImportToOnboardingCluster

func ImportToOnboardingCluster(ctx context.Context, dir string, options ...wait.Option) (*unstructured.UnstructuredList, error)

ImportToOnboardingCluster applies a set of resources from a directory to the onboarding cluster

func ImportToPlatformCluster added in v0.3.0

func ImportToPlatformCluster(ctx context.Context, c *envconf.Config, dir string, options ...wait.Option) (*unstructured.UnstructuredList, error)

ImportToPlatformCluster applies a set of resources from a directory to the platform cluster

func MCPConfig added in v0.3.0

func MCPConfig(ctx context.Context, platformCluster *envconf.Config, mcpName string) (*envconf.Config, error)

McpConfig is a utility function to return an environment config to work with the mcp cluster and default namespace.

func OnboardingConfig

func OnboardingConfig() (*envconf.Config, error)

OnboardingConfig is a utility function to return an environment config to work with the onboarding cluster and default namespace In scenarios where you work with multiple onboarding clusters, use ConfigByPrefix instead

Types

type ClusterProvider added in v0.3.0

type ClusterProvider interface {
	KubeConfig(string, bool) (string, error)
	List() ([]string, error)
}

type ListResources added in v0.3.0

type ListResources interface {
	List(ctx context.Context, objs k8s.ObjectList, opts ...k8sresources.ListOption) error
}

Jump to