Documentation
¶
Index ¶
- func CreateObjectFromTemplate(ctx context.Context, cfg *envconf.Config, template string, data interface{}) (*unstructured.Unstructured, error)
- func CreateObjectsFromDir(ctx context.Context, cfg *envconf.Config, dir string) (*unstructured.UnstructuredList, error)
- func CreateObjectsFromTemplateFile(ctx context.Context, cfg *envconf.Config, filePath string, data interface{}) (*unstructured.UnstructuredList, error)
- func DeleteObject(ctx context.Context, c *envconf.Config, obj k8s.Object, options ...wait.Option) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateObjectFromTemplate ¶
func CreateObjectFromTemplate(ctx context.Context, cfg *envconf.Config, template string, data interface{}) (*unstructured.Unstructured, error)
CreateObjectFromTemplate creates a single object by first applying the passed in data to a template
func CreateObjectsFromDir ¶
func CreateObjectsFromDir(ctx context.Context, cfg *envconf.Config, dir string) (*unstructured.UnstructuredList, error)
CreateObjectsFromDir creates objects specified by a file on the file system
func CreateObjectsFromTemplateFile ¶
func CreateObjectsFromTemplateFile(ctx context.Context, cfg *envconf.Config, filePath string, data interface{}) (*unstructured.UnstructuredList, error)
CreateObjectsFromTemplateFile creates objects by first applying the passed data to a template file on the file system
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.